Module algae::prelude

source ·

Modules

Structs

Enums

Traits

Functions

  • Combines two hashes into a single hash
  • Merges two hashes into a string
  • Creates a Merkle tree from a slice of data
  • This function takes in the index and calculates the height of the node This function is an iterative function as we might have to subtract the largest left_most tree.
  • Verify that the datum hash with a vector of proofs will produce the Merkle root. Also need the index of datum and leaf_size, the total number of leaves.
  • This function takes in the index and calculates if the node is the right child node or not. If the node is the tree root it will still give the answer as if it is a child of a node. This function is an iterative function as we might have to subtract the largest left_most tree.
  • Takes the hash of the given information to the second degree
  • This function takes in the index and calculates the index of the sibling.

Type Definitions