Function algae::prelude::get_node_height
source · pub fn get_node_height(index: usize) -> usizeExpand description
This function takes in the index and calculates the height of the node This function is an iterative function as we might have to subtract the largest left_most tree.